@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pornstars;
 use strict;
 use Acme::MetaSyntactic::MultiList;
 our @ISA = qw( Acme::MetaSyntactic::MultiList );
-our $VERSION = '1.005';
+our $VERSION = '1.006';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -55,6 +55,12 @@ Sbastien Aperghis-Tramoni.
 
 =item *
 
+2012-09-10 - v1.006
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.018.
+
+=item *
+
 2012-08-27 - v1.005
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.016.
@@ -527,7 +533,6 @@ Kelly_Wells
 Keri_Sable
 Keri_Windsor
 Kiki_Daire
-Kiko_Wu
 Kimberly_Carson
 Kimberly_Kane
 Kim_Chambers
